Re: [PATCH] net: usb: allow MTU that is a multiple of USB packet size

From: Sergei Shtylyov
Date: Thu May 07 2015 - 09:24:39 EST


Hello.

On 5/7/2015 12:49 PM, Ruslan Bilovol wrote:

Current usbnet driver rejects setting MTU that is a multiple
of USB endpoint's wMaxPacketSize size. However, it may only
lead to possible performance degradation but is not so
critical that its using should be prohibited. So allow it
but also warn user about possible issue.

Signed-off-by: Ruslan Bilovol <ruslan.bilovol@xxxxxxxxx>
---
drivers/net/usb/usbnet.c | 6 ++++--
1 file changed, 4 insertions(+), 2 deletions(-)

diff --git a/drivers/net/usb/usbnet.c b/drivers/net/usb/usbnet.c
index 733f4fe..09dc848 100644
--- a/drivers/net/usb/usbnet.c
+++ b/drivers/net/usb/usbnet.c
@@ -382,9 +382,11 @@ int usbnet_change_mtu (struct net_device *net, int new_mtu)

if (new_mtu <= 0)
return -EINVAL;
// no second zero-length packet read wanted after mtu-sized packets
if ((ll_mtu % dev->maxpacket) == 0)
- return -EDOM;
+ netdev_warn(dev->net, "MTU %d is a multiple of USB wMaxPacketSize (%d),"
+ " consider possible performance degradation\n",

Please do not wrap the kernel messages, it impedes grepping for them. scripts/checkpatch.pl is aware of this rule.
@@ -382,9 +382,11 @@ int usbnet_change_mtu (struct net_device *net, int new_mtu)
if (new_mtu <= 0)
return -EINVAL;
- // no second zero-length packet read wanted after mtu-sized packets
+ /* warn about second zero-length packet read after mtu-sized packets */
if ((ll_mtu % dev->maxpacket) == 0)

WBR, Sergei

--
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to majordomo@xxxxxxxxxxxxxxx
More majordomo info at http://vger.kernel.org/majordomo-info.html
Please read the FAQ at http://www.tux.org/lkml/